<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://involvz.com/
 * @since      1.0.0
 *
 * @package    tagsyncer
 * @subpackage tagsyncer/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    tagsyncer
 * @subpackage tagsyncer/includes
 * @author     Involvz <data@involvz.com>
 */
class tagsyncer {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      tagsyncer_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'GTM_VERSION' ) ) {
			$this->version = GTM_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'tagsyncer';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		
		// $this->define('gtmwp_frontend_compile_datalayer', array($this, 'tagsyncer_gtmwp_frontend_datalayer'));

		
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - tagsyncer_Loader. Orchestrates the hooks of the plugin.
	 * - tagsyncer_i18n. Defines internationalization functionality.
	 * - tagsyncer_Admin. Defines all hooks for the admin area.
	 * - tagsyncer_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-tagsyncer-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-tagsyncer-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-tagsyncer-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-tagsyncer-public.php';

		$this->loader = new tagsyncer_Loader();

		

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the tagsyncer_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new tagsyncer_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new tagsyncer_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'tagsyncer_add_google_tag_manager_menu', 10);
		$this->loader->add_action( 'admin_init', $plugin_admin, 'tagsyncer_google_tag_manager_register_settings');
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'display_gtm_notice');

		$this->loader->add_action('admin_init', $plugin_admin, 'tagsyncer_google_tag_manager_save_settings');
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new tagsyncer_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$this->loader->add_action( 'init', $plugin_public, 'save_google_tag_manager_script' );

		$this->loader->add_action( 'wp_head', $plugin_public, 'tagsyncer_gtmwc_wp_header_enhanced_wc');

		$this->loader->add_action('wp_footer', $plugin_public, 'tagsyncer_google_tag_manager_scroll_tracking_script');

		$this->loader->add_filter('gtmwp_frontend_compile_datalayer', $plugin_public, 'tagsyncer_gtmwp_frontend_datalayer', 10, 1);

		$options1 = get_option('tagsyncer_tab1_option_name');
		$options3 = get_option('tagsyncer_tab3_option_name');
		$wc_track_enable = isset($options3['wc_track_enable']) ? $options3['wc_track_enable'] : 0;
		$el_form_track_enable = isset($options3['elform_enable']) ? $options3['elform_enable'] : 0;
		$gtm_id = isset($options1['gtm_id']) ? esc_attr($options1['gtm_id']) : '';
		if ($wc_track_enable && !empty($gtm_id)) {
			
			include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

			if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
				require_once dirname( __FILE__ ) . '/../public/includes/wc-functions.php';
			}
		}
		if ($el_form_track_enable && !empty($gtm_id)) {
			
			include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

			if ( did_action( 'elementor/loaded' ) ) {
				require_once dirname( __FILE__ ) . '/../public/includes/el-functions.php';
			}
		}

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    tagsyncer_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
